use strict;
use warnings;

package Hash::Case::Lower;
use base 'Hash::Case';

use Log::Report 'hash-case';

=chapter NAME

Hash::Case::Lower - hash with enforced lower cased keys

=chapter SYNOPSIS

 use Hash::Case::Lower;
 tie my(%lchash), 'Hash::Case::Lower';
 $lchash{StraNGeKeY} = 3;
 print keys %lchash;  # strangekey

=chapter DESCRIPTION

Hash::Case::Lower extends M<Hash::Case>, which lets you play various
trics with hash keys. In this implementation, the fake hash is case
insensitive and the keys stored in lower-case.

=chapter METHODS

=section Constructors

=tie tie HASH, 'Hash::Case::Lower', [VALUES,] OPTIONS

Define HASH to have only lower cased keys.  The hash is initialized with
the VALUES, specified as ref-array (with key value pairs) or ref-hash.
Currently, there are no OPTIONS defined.

=cut

sub init($)
{   my ($self, $args) = @_;

    $self->SUPER::native_init($args);

    error __x"no options possible for {pkg}", pkg => __PACKAGE__
        if keys %$args;

    $self;
}

sub FETCH($)  { $_[0]->{lc $_[1]} }
sub STORE($$) { $_[0]->{lc $_[1]} = $_[2] }
sub EXISTS($) { exists $_[0]->{lc $_[1]} }
sub DELETE($) { delete $_[0]->{lc $_[1]} }

1;
